@@ -67,7 +67,7 @@ def repeat(
 
     Returns:
         Callable[[Language, Example], Iterator[Example]]: The repeated augmenter
-    
+
     Example:
         >>> augmenter = augmenty.load("char_swap.v1", level=.02)
         >>> repeated_augmenter = augmenty.repeat(augmenter=aug, n=3)
@@ -76,21 +76,20 @@ def repeat(
     def __augment(nlp: Language, example: Example):
         for i in range(n):
             for e in augmenter(nlp, example):
-                yield e 
+                yield e
 
     return __augment
 
 
 def yield_original(
-    augmenter: Callable[[Language, Example], Iterator[Example]],
-    doc_level: float=1.0
+    augmenter: Callable[[Language, Example], Iterator[Example]], doc_level: float = 1.0
 ) -> Callable[[Language, Example], Iterator[Example]]:
     """Wraps and augmented such that it yields both the original and augmented example.
 
     Args:
         augmenter (Callable[[Language, Example], Iterator[Example]]): A spaCy augmenters.
         doc_level (float, optional): The percentage of documents the augmenter should be applied to.
-            Only yield the original when the original doc is augmented. 
+            Only yield the original when the original doc is augmented.
 
     Returns:
         Callable[[Language, Example], Iterator[Example]]: The augmenter, which now yields both the original and augmented example.
